from setuptools import setup, find_packages

setup(
    name='FB-DJANGO-APP',
    version='0.1',
    packages=find_packages(),
    install_requires=[
        'Django>=3.2',  # Add other dependencies if required
    ],
)
